@@ -207,8 +207,8 @@ class RequestHandler(tornado.web.RequestHandler):
             content_type = response.headers.get('Content-Type', '').split(';')[0]
             response.data = None
             self.log.debug(
-                'Got response for "%s" (code = %s, content_type = %s): %.100s',
-                name, response.code, content_type, response.body,
+                'Got response for "%s" (code = %s, content_type = %s): %.200s',
+                name, response.code, content_type, response.body.decode('utf-8', errors='replace'),
             )
             try:
                 if 'xml' in content_type:
