@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
-from lxml import etree
 from tornado.escape import json_decode
 
 from tortik.util import HTTPError
+from tortik.util.xml_etree import parse, ParseError
 
 try:
     import httplib  # py2
@@ -14,9 +14,8 @@ def parse_xml(response):
     if response.code == 599 or response.buffer is None:
         raise HTTPError(httplib.SERVICE_UNAVAILABLE, 'Response timeout or no body buffer')
     try:
-        parser = etree.XMLParser(remove_blank_text=True)
-        return etree.parse(response.buffer, parser=parser)
-    except etree.ParseError:
+        return parse(response.buffer)
+    except ParseError:
         raise HTTPError(httplib.SERVICE_UNAVAILABLE, 'Unable to parse xml')
 
 
